# Meshfiles for testing
## Filenames for each format are as follows

* Shape:
  * grid_fire.shp
* Exodus:
  * outCSne8.g
* SCRIP:
  * outCSne30_vortex.nc
  * outCSne8.nc
  * outRLL1deg_vortex.nc
  * ov_RLL10deg_CSne4_vortex.nc
* UGRID:
  * outCSne30.ug
  * outRLL1deg.ug
  * ov_RLL10deg_CSne4.ug
  * outCSne30_var2.ug
